@@ -1,6 +1,6 @@
 package ElasticSearch::Transport;
 {
-  $ElasticSearch::Transport::VERSION = '0.44';
+  $ElasticSearch::Transport::VERSION = '0.45';
 }
 
 use strict;
@@ -623,7 +623,7 @@ happens via the main L<ElasticSearch> class.
         transport   => 'httplite',
         timeout     => '10',
         no_refresh  => 0 | 1,
-        delate      => 0 | 1,
+        deflate     => 0 | 1,
     );
 
     my $t = $e->transport;
